@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -398,8 +398,8 @@ print_out (TmaidWindow *tmaid,
   loop:
   /* ja:終了処理 */
   g_object_unref (gc);
-  gdk_pixbuf_unref (pixbuf);
-  gdk_pixmap_unref (pixmap);
+  g_object_unref (pixbuf);
+  g_object_unref (pixmap);
 #ifdef G_OS_WIN32
   if (EndDoc (prncfg->pd.hDC) <= 0)
     {
